summaryrefslogtreecommitdiffstats
path: root/core/java/android/content/ContentResolver.java
diff options
context:
space:
mode:
authorFred Quintana <fredq@google.com>2010-03-30 15:16:21 -0700
committerFred Quintana <fredq@google.com>2010-03-30 17:31:52 -0700
commitd5e4fdc8a4743abc0d9fe3cb952a78f9ad078c6b (patch)
tree368fa8665a93e3e524b0d020fe33f5febb58661d /core/java/android/content/ContentResolver.java
parent8acdb911f4b9c38d1cafd3ab464d6bec54564c84 (diff)
downloadframeworks_base-d5e4fdc8a4743abc0d9fe3cb952a78f9ad078c6b.zip
frameworks_base-d5e4fdc8a4743abc0d9fe3cb952a78f9ad078c6b.tar.gz
frameworks_base-d5e4fdc8a4743abc0d9fe3cb952a78f9ad078c6b.tar.bz2
some changes due to an API review
- make EntityIterator extend Iterator and thus not throw a RemoteException, instead converting it into a RuntimeException. - rename ActiveSyncInfo to SyncInfo - change getActiveSync to getCurrentSync - remove the accessors in SyncInfo and instead make the final fields publicly accessible - made AbstractThreadedSyncAdapter.cancelSync not take a thread Change-Id: I99fde5585bc5f1e95f4873ffbba189074a8d6372 http://b/issue?id=2553539 http://b/issue?id=2553541 http://b/issue?id=2553550
Diffstat (limited to 'core/java/android/content/ContentResolver.java')
-rw-r--r--core/java/android/content/ContentResolver.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/java/android/content/ContentResolver.java b/core/java/android/content/ContentResolver.java
index d3cc4df..1cb2353 100644
--- a/core/java/android/content/ContentResolver.java
+++ b/core/java/android/content/ContentResolver.java
@@ -1179,11 +1179,11 @@ public abstract class ContentResolver {
/**
* If a sync is active returns the information about it, otherwise returns false.
* @return the ActiveSyncInfo for the currently active sync or null if one is not active.
*/
- public static ActiveSyncInfo getActiveSync() {
+ public static SyncInfo getCurrentSync() {
try {
- return getContentService().getActiveSync();
+ return getContentService().getCurrentSync();
} catch (RemoteException e) {
throw new RuntimeException("the ContentService should always be reachable", e);
}
@@ -1179,11 +1179,11 @@ public abstract class ContentResolver {
/**
* If a sync is active returns the information about it, otherwise returns false.
- * @return the ActiveSyncInfo for the currently active sync or null if one is not active.
+ * @return the SyncInfo for the currently active sync or null if one is not active.
*/